@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="cs_CZ" sourcelanguage="en">
+<TS version="2.1" language="cs_CZ" sourcelanguage="en_US">
 <context>
     <name>About</name>
     <message>
@@ -42,47 +42,47 @@
 <context>
     <name>Benchmark</name>
     <message>
-        <location filename="../../src/benchmark.cpp" line="240"/>
+        <location filename="../../src/benchmark.cpp" line="232"/>
         <source>Preparing...</source>
         <translation>Příprava...</translation>
     </message>
     <message>
-        <location filename="../../src/benchmark.cpp" line="258"/>
+        <location filename="../../src/benchmark.cpp" line="254"/>
         <source>Sequential Read %1/%2</source>
         <translation>Sekvenční čení %1/%2</translation>
     </message>
     <message>
-        <location filename="../../src/benchmark.cpp" line="268"/>
+        <location filename="../../src/benchmark.cpp" line="264"/>
         <source>Sequential Write %1/%2</source>
         <translation>Sekvenční zápis %1/%2</translation>
     </message>
     <message>
-        <location filename="../../src/benchmark.cpp" line="278"/>
+        <location filename="../../src/benchmark.cpp" line="274"/>
         <source>Sequential Mix %1/%2</source>
         <translation>Sekvenční mix %1/%2</translation>
     </message>
     <message>
-        <location filename="../../src/benchmark.cpp" line="377"/>
+        <location filename="../../src/benchmark.cpp" line="405"/>
         <source>Could not obtain administrator privileges.</source>
         <translation>Nepodařilo se získat oprávnění správce.</translation>
     </message>
     <message>
-        <location filename="../../src/benchmark.cpp" line="262"/>
+        <location filename="../../src/benchmark.cpp" line="258"/>
         <source>Random Read %1/%2</source>
         <translation>Náhodné čtení %1/%2</translation>
     </message>
     <message>
-        <location filename="../../src/benchmark.cpp" line="272"/>
+        <location filename="../../src/benchmark.cpp" line="268"/>
         <source>Random Write %1/%2</source>
         <translation>Náhodný zápis %1/%2</translation>
     </message>
     <message>
-        <location filename="../../src/benchmark.cpp" line="282"/>
+        <location filename="../../src/benchmark.cpp" line="278"/>
         <source>Random Mix %1/%2</source>
         <translation>Náhodný mix %1/%2</translation>
     </message>
     <message>
-        <location filename="../../src/benchmark.cpp" line="289"/>
+        <location filename="../../src/benchmark.cpp" line="285"/>
         <source>Interval Time %1/%2 sec</source>
         <translation>Prodleva mezi testy %1/%2 sek</translation>
     </message>
@@ -91,68 +91,68 @@
     <name>MainWindow</name>
     <message>
         <location filename="../../src/mainwindow.ui" line="30"/>
-        <location filename="../../src/mainwindow.cpp" line="895"/>
+        <location filename="../../src/mainwindow.cpp" line="917"/>
         <source>All</source>
         <translation>Vše</translation>
     </message>
     <message>
-        <location filename="../../src/mainwindow.ui" line="352"/>
-        <location filename="../../src/mainwindow.ui" line="934"/>
-        <location filename="../../src/mainwindow.cpp" line="534"/>
+        <location filename="../../src/mainwindow.ui" line="351"/>
+        <location filename="../../src/mainwindow.ui" line="933"/>
+        <location filename="../../src/mainwindow.cpp" line="547"/>
         <source>Read</source>
         <translation>Čtení</translation>
     </message>
     <message>
-        <location filename="../../src/mainwindow.ui" line="521"/>
-        <location filename="../../src/mainwindow.ui" line="953"/>
-        <location filename="../../src/mainwindow.cpp" line="537"/>
+        <location filename="../../src/mainwindow.ui" line="520"/>
+        <location filename="../../src/mainwindow.ui" line="952"/>
+        <location filename="../../src/mainwindow.cpp" line="550"/>
         <source>Write</source>
         <translation>Zápis</translation>
     </message>
     <message>
-        <location filename="../../src/mainwindow.ui" line="687"/>
-        <location filename="../../src/mainwindow.cpp" line="540"/>
+        <location filename="../../src/mainwindow.ui" line="686"/>
+        <location filename="../../src/mainwindow.cpp" line="553"/>
         <source>Mix</source>
         <translation>Mix</translation>
     </message>
     <message>
-        <location filename="../../src/mainwindow.ui" line="221"/>
-        <location filename="../../src/mainwindow.cpp" line="423"/>
-        <location filename="../../src/mainwindow.cpp" line="427"/>
+        <location filename="../../src/mainwindow.ui" line="220"/>
+        <location filename="../../src/mainwindow.cpp" line="436"/>
+        <location filename="../../src/mainwindow.cpp" line="440"/>
         <source>MB/s</source>
         <translation>MB/s</translation>
     </message>
     <message>
-        <location filename="../../src/mainwindow.ui" line="226"/>
+        <location filename="../../src/mainwindow.ui" line="225"/>
         <source>GB/s</source>
         <translation>GB/s</translation>
     </message>
     <message>
-        <location filename="../../src/mainwindow.ui" line="231"/>
-        <location filename="../../src/mainwindow.cpp" line="429"/>
-        <location filename="../../src/mainwindow.cpp" line="430"/>
+        <location filename="../../src/mainwindow.ui" line="230"/>
+        <location filename="../../src/mainwindow.cpp" line="442"/>
+        <location filename="../../src/mainwindow.cpp" line="443"/>
         <source>IOPS</source>
         <translation>IOPS</translation>
     </message>
     <message>
-        <location filename="../../src/mainwindow.ui" line="236"/>
-        <location filename="../../src/mainwindow.cpp" line="432"/>
-        <location filename="../../src/mainwindow.cpp" line="433"/>
+        <location filename="../../src/mainwindow.ui" line="235"/>
+        <location filename="../../src/mainwindow.cpp" line="445"/>
+        <location filename="../../src/mainwindow.cpp" line="446"/>
         <source>μs</source>
         <translation>μs</translation>
     </message>
     <message>
-        <location filename="../../src/mainwindow.ui" line="1018"/>
+        <location filename="../../src/mainwindow.ui" line="1017"/>
         <source>File</source>
         <translation>Soubor</translation>
     </message>
     <message>
-        <location filename="../../src/mainwindow.ui" line="1026"/>
+        <location filename="../../src/mainwindow.ui" line="1025"/>
         <source>Settings</source>
         <translation>Nastavení</translation>
     </message>
     <message>
-        <location filename="../../src/mainwindow.ui" line="1030"/>
+        <location filename="../../src/mainwindow.ui" line="1029"/>
         <source>Test Data</source>
         <translation>Testovací data</translation>
     </message>
@@ -302,81 +302,95 @@
         <translation>Použít O_DIRECT</translation>
     </message>
     <message>
-        <location filename="../../src/mainwindow.cpp" line="53"/>
+        <location filename="../../src/mainwindow.ui" line="1303"/>
+        <source>CoW detection</source>
+        <translation>Detekce CoW</translation>
+    </message>
+    <message>
+        <location filename="../../src/mainwindow.cpp" line="54"/>
         <source>The device is encrypted. Performance may drop.</source>
         <translation>Zařízení je šifrované. Výkon může poklesnout.</translation>
     </message>
     <message>
-        <location filename="../../src/mainwindow.cpp" line="345"/>
-        <location filename="../../src/mainwindow.cpp" line="439"/>
-        <location filename="../../src/mainwindow.cpp" line="507"/>
+        <location filename="../../src/mainwindow.cpp" line="352"/>
+        <location filename="../../src/mainwindow.cpp" line="452"/>
+        <location filename="../../src/mainwindow.cpp" line="520"/>
         <source>MiB</source>
         <translation>MiB</translation>
     </message>
     <message>
-        <location filename="../../src/mainwindow.cpp" line="349"/>
-        <location filename="../../src/mainwindow.cpp" line="507"/>
+        <location filename="../../src/mainwindow.cpp" line="356"/>
+        <location filename="../../src/mainwindow.cpp" line="520"/>
         <source>GiB</source>
         <translation>GiB</translation>
     </message>
     <message>
-        <location filename="../../src/mainwindow.cpp" line="507"/>
+        <location filename="../../src/mainwindow.cpp" line="520"/>
         <source>Bytes</source>
         <translation>Bajtů</translation>
     </message>
     <message>
-        <location filename="../../src/mainwindow.cpp" line="439"/>
-        <location filename="../../src/mainwindow.cpp" line="507"/>
+        <location filename="../../src/mainwindow.cpp" line="452"/>
+        <location filename="../../src/mainwindow.cpp" line="520"/>
         <source>KiB</source>
         <translation>KiB</translation>
     </message>
     <message>
-        <location filename="../../src/mainwindow.cpp" line="256"/>
-        <location filename="../../src/mainwindow.cpp" line="315"/>
+        <location filename="../../src/mainwindow.cpp" line="263"/>
+        <location filename="../../src/mainwindow.cpp" line="322"/>
         <source>Add a directory</source>
         <translation>Přidat adresář</translation>
     </message>
     <message>
-        <location filename="../../src/mainwindow.cpp" line="507"/>
+        <location filename="../../src/mainwindow.cpp" line="520"/>
         <source>TiB</source>
         <translation>TiB</translation>
     </message>
     <message>
-        <location filename="../../src/mainwindow.cpp" line="507"/>
+        <location filename="../../src/mainwindow.cpp" line="520"/>
         <source>PiB</source>
         <translation>PiB</translation>
     </message>
     <message>
-        <location filename="../../src/mainwindow.cpp" line="870"/>
-        <location filename="../../src/mainwindow.cpp" line="871"/>
-        <location filename="../../src/mainwindow.cpp" line="872"/>
-        <location filename="../../src/mainwindow.cpp" line="873"/>
-        <location filename="../../src/mainwindow.cpp" line="874"/>
+        <location filename="../../src/mainwindow.cpp" line="892"/>
+        <location filename="../../src/mainwindow.cpp" line="893"/>
+        <location filename="../../src/mainwindow.cpp" line="894"/>
+        <location filename="../../src/mainwindow.cpp" line="895"/>
+        <location filename="../../src/mainwindow.cpp" line="896"/>
         <source>Stop</source>
         <translation>Stop</translation>
     </message>
     <message>
-        <location filename="../../src/mainwindow.cpp" line="922"/>
+        <location filename="../../src/mainwindow.cpp" line="944"/>
         <source>Stopping...</source>
         <translation>Zastavování…</translation>
     </message>
     <message>
-        <location filename="../../src/mainwindow.cpp" line="932"/>
+        <location filename="../../src/mainwindow.cpp" line="954"/>
         <source>Not available</source>
         <translation>Není k dispozici</translation>
     </message>
     <message>
-        <location filename="../../src/mainwindow.cpp" line="932"/>
+        <location filename="../../src/mainwindow.cpp" line="954"/>
         <source>Directory is not specified.</source>
-        <translation>Není zadána složka.</translation>
+        <translation>Není zadán adresář.</translation>
+    </message>
+    <message>
+        <location filename="../../src/mainwindow.cpp" line="1059"/>
+        <source>Copy-on-Write (CoW) is enabled on the selected directory.</source>
+        <translation>Na vybraném adresáři je povoleno kopírování při zápisu (CoW).</translation>
+    </message>
+    <message>
+        <location filename="../../src/mainwindow.cpp" line="1060"/>
+        <source>This may affect performance results. Would you like to create a new subdirectory with CoW disabled?</source>
+        <translation>Toto může ovlivnit výsledky výkonu. Chcete vytvořit nový podadresář s vypnutým CoW?</translation>
     </message>
     <message>
-        <location filename="../../src/mainwindow.cpp" line="935"/>
         <source>Confirmation</source>
-        <translation>Potvrzení</translation>
+        <translation type="vanished">Potvrzení</translation>
     </message>
     <message>
-        <location filename="../../src/mainwindow.cpp" line="948"/>
+        <location filename="../../src/mainwindow.cpp" line="964"/>
         <source>Benchmark Failed</source>
         <translation>Test se nezdařil</translation>
     </message>
@@ -414,7 +428,7 @@
         <translation>&lt;h1&gt;%1 MB/s&lt;br/&gt;%2 GB/s&lt;br/&gt;%3 IOPS&lt;br/&gt;%4 μs&lt;/h1&gt;</translation>
     </message>
     <message>
-        <location filename="../../src/mainwindow.cpp" line="193"/>
+        <location filename="../../src/mainwindow.cpp" line="200"/>
         <source>No FIO was found. Please install FIO before using KDiskMark.</source>
         <translation>FIO nenalezeno. Aby bylo možné používat KDiskMark, je třeba nainstalovat FIO.</translation>
     </message>
