@@ -5,43 +5,36 @@
     <name>About</name>
     <message>
         <location filename="../../src/about.ui" line="17"/>
-        <location filename="../../build/kdiskmark_autogen/include/ui_about.h" line="133"/>
         <source>About KDiskMark</source>
         <translation>KDiskMark について</translation>
     </message>
     <message>
         <location filename="../../src/about.ui" line="62"/>
-        <location filename="../../build/kdiskmark_autogen/include/ui_about.h" line="135"/>
         <source>Version:</source>
         <translation>バージョン:</translation>
     </message>
     <message>
         <location filename="../../src/about.ui" line="88"/>
-        <location filename="../../build/kdiskmark_autogen/include/ui_about.h" line="136"/>
         <source>License:</source>
         <translation>ライセンス:</translation>
     </message>
     <message>
         <location filename="../../src/about.ui" line="114"/>
-        <location filename="../../build/kdiskmark_autogen/include/ui_about.h" line="137"/>
         <source>Author:</source>
         <translation>作者:</translation>
     </message>
     <message>
         <location filename="../../src/about.ui" line="146"/>
-        <location filename="../../build/kdiskmark_autogen/include/ui_about.h" line="138"/>
         <source>E-mail:</source>
         <translation>E-mail:</translation>
     </message>
     <message>
         <location filename="../../src/about.ui" line="178"/>
-        <location filename="../../build/kdiskmark_autogen/include/ui_about.h" line="139"/>
         <source>Flexible I/O Tester:</source>
         <translation>柔軟な I/O テスター:</translation>
     </message>
     <message>
         <location filename="../../src/about.ui" line="204"/>
-        <location filename="../../build/kdiskmark_autogen/include/ui_about.h" line="140"/>
         <source>Application Icon:</source>
         <translation>アプリアイコン:</translation>
     </message>
@@ -49,47 +42,47 @@
 <context>
     <name>Benchmark</name>
     <message>
-        <location filename="../../src/benchmark.cpp" line="240"/>
+        <location filename="../../src/benchmark.cpp" line="232"/>
         <source>Preparing...</source>
         <translation>準備中...</translation>
     </message>
     <message>
-        <location filename="../../src/benchmark.cpp" line="258"/>
+        <location filename="../../src/benchmark.cpp" line="254"/>
         <source>Sequential Read %1/%2</source>
         <translation>Sequential Read %1/%2</translation>
     </message>
     <message>
-        <location filename="../../src/benchmark.cpp" line="262"/>
+        <location filename="../../src/benchmark.cpp" line="258"/>
         <source>Random Read %1/%2</source>
         <translation>Random Read %1/%2</translation>
     </message>
     <message>
-        <location filename="../../src/benchmark.cpp" line="268"/>
+        <location filename="../../src/benchmark.cpp" line="264"/>
         <source>Sequential Write %1/%2</source>
         <translation>Sequential Write %1/%2</translation>
     </message>
     <message>
-        <location filename="../../src/benchmark.cpp" line="272"/>
+        <location filename="../../src/benchmark.cpp" line="268"/>
         <source>Random Write %1/%2</source>
         <translation>Random Write %1/%2</translation>
     </message>
     <message>
-        <location filename="../../src/benchmark.cpp" line="278"/>
+        <location filename="../../src/benchmark.cpp" line="274"/>
         <source>Sequential Mix %1/%2</source>
         <translation>Sequential Mix %1/%2</translation>
     </message>
     <message>
-        <location filename="../../src/benchmark.cpp" line="282"/>
+        <location filename="../../src/benchmark.cpp" line="278"/>
         <source>Random Mix %1/%2</source>
         <translation>Random Mix %1/%2</translation>
     </message>
     <message>
-        <location filename="../../src/benchmark.cpp" line="289"/>
+        <location filename="../../src/benchmark.cpp" line="285"/>
         <source>Interval Time %1/%2 sec</source>
         <translation>インターバル %1/%2 sec</translation>
     </message>
     <message>
-        <location filename="../../src/benchmark.cpp" line="377"/>
+        <location filename="../../src/benchmark.cpp" line="405"/>
         <source>Could not obtain administrator privileges.</source>
         <translation>管理者権限を取得できませんでした。</translation>
     </message>
@@ -98,334 +91,306 @@
     <name>MainWindow</name>
     <message>
         <location filename="../../src/mainwindow.ui" line="30"/>
-        <location filename="../../build/kdiskmark_autogen/include/ui_mainwindow.h" line="659"/>
-        <location filename="../../src/mainwindow.cpp" line="895"/>
+        <location filename="../../src/mainwindow.cpp" line="917"/>
         <source>All</source>
         <translation>All</translation>
     </message>
     <message>
-        <location filename="../../src/mainwindow.ui" line="221"/>
-        <location filename="../../build/kdiskmark_autogen/include/ui_mainwindow.h" line="662"/>
-        <location filename="../../src/mainwindow.cpp" line="423"/>
-        <location filename="../../src/mainwindow.cpp" line="427"/>
+        <location filename="../../src/mainwindow.ui" line="220"/>
+        <location filename="../../src/mainwindow.cpp" line="436"/>
+        <location filename="../../src/mainwindow.cpp" line="440"/>
         <source>MB/s</source>
         <translation>MB/s</translation>
     </message>
     <message>
-        <location filename="../../src/mainwindow.ui" line="226"/>
-        <location filename="../../build/kdiskmark_autogen/include/ui_mainwindow.h" line="663"/>
+        <location filename="../../src/mainwindow.ui" line="225"/>
         <source>GB/s</source>
         <translation>GB/s</translation>
     </message>
     <message>
-        <location filename="../../src/mainwindow.ui" line="231"/>
-        <location filename="../../build/kdiskmark_autogen/include/ui_mainwindow.h" line="664"/>
-        <location filename="../../src/mainwindow.cpp" line="429"/>
-        <location filename="../../src/mainwindow.cpp" line="430"/>
+        <location filename="../../src/mainwindow.ui" line="230"/>
+        <location filename="../../src/mainwindow.cpp" line="442"/>
+        <location filename="../../src/mainwindow.cpp" line="443"/>
         <source>IOPS</source>
         <translation>IOPS</translation>
     </message>
     <message>
-        <location filename="../../src/mainwindow.ui" line="236"/>
-        <location filename="../../build/kdiskmark_autogen/include/ui_mainwindow.h" line="665"/>
-        <location filename="../../src/mainwindow.cpp" line="432"/>
-        <location filename="../../src/mainwindow.cpp" line="433"/>
+        <location filename="../../src/mainwindow.ui" line="235"/>
+        <location filename="../../src/mainwindow.cpp" line="445"/>
+        <location filename="../../src/mainwindow.cpp" line="446"/>
         <source>μs</source>
         <translation>μs</translation>
     </message>
     <message>
-        <location filename="../../src/mainwindow.ui" line="352"/>
-        <location filename="../../src/mainwindow.ui" line="934"/>
-        <location filename="../../build/kdiskmark_autogen/include/ui_mainwindow.h" line="668"/>
-        <location filename="../../build/kdiskmark_autogen/include/ui_mainwindow.h" line="671"/>
-        <location filename="../../src/mainwindow.cpp" line="534"/>
+        <location filename="../../src/mainwindow.ui" line="351"/>
+        <location filename="../../src/mainwindow.ui" line="933"/>
+        <location filename="../../src/mainwindow.cpp" line="547"/>
         <source>Read</source>
         <translation>Read</translation>
     </message>
     <message>
-        <location filename="../../src/mainwindow.ui" line="521"/>
-        <location filename="../../src/mainwindow.ui" line="953"/>
-        <location filename="../../build/kdiskmark_autogen/include/ui_mainwindow.h" line="669"/>
-        <location filename="../../build/kdiskmark_autogen/include/ui_mainwindow.h" line="672"/>
-        <location filename="../../src/mainwindow.cpp" line="537"/>
+        <location filename="../../src/mainwindow.ui" line="520"/>
+        <location filename="../../src/mainwindow.ui" line="952"/>
+        <location filename="../../src/mainwindow.cpp" line="550"/>
         <source>Write</source>
         <translation>Write</translation>
     </message>
     <message>
-        <location filename="../../src/mainwindow.ui" line="687"/>
-        <location filename="../../build/kdiskmark_autogen/include/ui_mainwindow.h" line="670"/>
-        <location filename="../../src/mainwindow.cpp" line="540"/>
+        <location filename="../../src/mainwindow.ui" line="686"/>
+        <location filename="../../src/mainwindow.cpp" line="553"/>
         <source>Mix</source>
         <translation>Mix</translation>
     </message>
     <message>
-        <location filename="../../src/mainwindow.ui" line="1018"/>
-        <location filename="../../build/kdiskmark_autogen/include/ui_mainwindow.h" line="673"/>
+        <location filename="../../src/mainwindow.ui" line="1017"/>
         <source>File</source>
         <translation>ファイル</translation>
     </message>
     <message>
-        <location filename="../../src/mainwindow.ui" line="1026"/>
-        <location filename="../../build/kdiskmark_autogen/include/ui_mainwindow.h" line="674"/>
+        <location filename="../../src/mainwindow.ui" line="1025"/>
         <source>Settings</source>
         <translation>設定</translation>
     </message>
     <message>
-        <location filename="../../src/mainwindow.ui" line="1030"/>
-        <location filename="../../build/kdiskmark_autogen/include/ui_mainwindow.h" line="675"/>
+        <location filename="../../src/mainwindow.ui" line="1029"/>
         <source>Test Data</source>
         <translation>テストデータ</translation>
     </message>
     <message>
         <location filename="../../src/mainwindow.ui" line="1047"/>
-        <location filename="../../build/kdiskmark_autogen/include/ui_mainwindow.h" line="676"/>
         <source>Profile</source>
         <translation>プロファイル</translation>
     </message>
     <message>
         <location filename="../../src/mainwindow.ui" line="1063"/>
-        <location filename="../../build/kdiskmark_autogen/include/ui_mainwindow.h" line="677"/>
         <source>Help</source>
         <translation>ヘルプ</translation>
     </message>
     <message>
         <location filename="../../src/mainwindow.ui" line="1067"/>
-        <location filename="../../build/kdiskmark_autogen/include/ui_mainwindow.h" line="678"/>
         <source>Language</source>
         <translation>言語</translation>
     </message>
     <message>
         <location filename="../../src/mainwindow.ui" line="1075"/>
-        <location filename="../../build/kdiskmark_autogen/include/ui_mainwindow.h" line="679"/>
         <source>Theme</source>
         <translation>テーマ</translation>
     </message>
     <message>
         <location filename="../../src/mainwindow.ui" line="1091"/>
-        <location filename="../../build/kdiskmark_autogen/include/ui_mainwindow.h" line="634"/>
         <source>About KDiskMark</source>
         <translation>KDiskMark について</translation>
     </message>
     <message>
         <location filename="../../src/mainwindow.ui" line="1096"/>
-        <location filename="../../build/kdiskmark_autogen/include/ui_mainwindow.h" line="635"/>
         <source>Queues &amp;&amp; Threads</source>
         <translation>キュー数 &amp;&amp; スレッド数</translation>
     </message>
     <message>
         <location filename="../../src/mainwindow.ui" line="1101"/>
-        <location filename="../../build/kdiskmark_autogen/include/ui_mainwindow.h" line="636"/>
         <source>Copy</source>
         <translation>コピー</translation>
     </message>
     <message>
         <location filename="../../src/mainwindow.ui" line="1106"/>
-        <location filename="../../build/kdiskmark_autogen/include/ui_mainwindow.h" line="637"/>
         <source>Save</source>
         <translation>保存</translation>
     </message>
     <message>
         <location filename="../../src/mainwindow.ui" line="1111"/>
-        <location filename="../../build/kdiskmark_autogen/include/ui_mainwindow.h" line="638"/>
         <source>Exit</source>
         <translation>終了</translation>
     </message>
     <message>
         <location filename="../../src/mainwindow.ui" line="1122"/>
-        <location filename="../../build/kdiskmark_autogen/include/ui_mainwindow.h" line="639"/>
         <source>Default</source>
         <translation>デフォルト</translation>
     </message>
     <message>
         <location filename="../../src/mainwindow.ui" line="1130"/>
-        <location filename="../../build/kdiskmark_autogen/include/ui_mainwindow.h" line="640"/>
         <source>Peak Performance</source>
         <translation>ピーク性能</translation>
     </message>
     <message>
         <location filename="../../src/mainwindow.ui" line="1138"/>
-        <location filename="../../build/kdiskmark_autogen/include/ui_mainwindow.h" line="641"/>
         <source>Real World Performance</source>
         <translation>現実性能</translation>
     </message>
     <message>
         <location filename="../../src/mainwindow.ui" line="1146"/>
-        <location filename="../../build/kdiskmark_autogen/include/ui_mainwindow.h" line="642"/>
         <source>Default [+Mix]</source>
         <translation>デフォルト [+Mix]</translation>
     </message>
     <message>
         <location filename="../../src/mainwindow.ui" line="1154"/>
-        <location filename="../../build/kdiskmark_autogen/include/ui_mainwindow.h" line="643"/>
         <source>Peak Performance [+Mix]</source>
         <translation>ピーク性能 [+Mix]</translation>
     </message>
     <message>
         <location filename="../../src/mainwindow.ui" line="1162"/>
-        <location filename="../../build/kdiskmark_autogen/include/ui_mainwindow.h" line="644"/>
         <source>Real World Performance [+Mix]</source>
         <translation>現実性能 [+Mix]</translation>
     </message>
     <message>
         <location filename="../../src/mainwindow.ui" line="1173"/>
-        <location filename="../../build/kdiskmark_autogen/include/ui_mainwindow.h" line="645"/>
         <source>Flush Pagecache</source>
         <translation>ページキャッシュをフラッシュ</translation>
     </message>
     <message>
         <location filename="../../src/mainwindow.ui" line="1181"/>
-        <location filename="../../build/kdiskmark_autogen/include/ui_mainwindow.h" line="646"/>
         <source>Demo</source>
         <translation>デモ</translation>
     </message>
     <message>
         <location filename="../../src/mainwindow.ui" line="1192"/>
-        <location filename="../../build/kdiskmark_autogen/include/ui_mainwindow.h" line="647"/>
         <source>Read and Write [+Mix]</source>
         <translation>Read and Write [+Mix]</translation>
     </message>
     <message>
         <location filename="../../src/mainwindow.ui" line="1200"/>
-        <location filename="../../build/kdiskmark_autogen/include/ui_mainwindow.h" line="648"/>
         <source>Read [+Mix]</source>
         <translation>Read [+Mix]</translation>
     </message>
     <message>
         <location filename="../../src/mainwindow.ui" line="1208"/>
-        <location filename="../../build/kdiskmark_autogen/include/ui_mainwindow.h" line="649"/>
         <source>Write [+Mix]</source>
         <translation>Write [+Mix]</translation>
     </message>
     <message>
         <location filename="../../src/mainwindow.ui" line="1219"/>
-        <location filename="../../build/kdiskmark_autogen/include/ui_mainwindow.h" line="650"/>
         <source>Random</source>
         <translation>ランダム</translation>
     </message>
     <message>
         <location filename="../../src/mainwindow.ui" line="1227"/>
-        <location filename="../../build/kdiskmark_autogen/include/ui_mainwindow.h" line="651"/>
         <source>Fill with zeros</source>
         <translation>All 0x00 (0Fill)</translation>
     </message>
     <message>
         <location filename="../../src/mainwindow.ui" line="1238"/>
-        <location filename="../../build/kdiskmark_autogen/include/ui_mainwindow.h" line="652"/>
         <source>Standard Preset</source>
         <translation>標準プリセット</translation>
     </message>
     <message>
         <location filename="../../src/mainwindow.ui" line="1246"/>
-        <location filename="../../build/kdiskmark_autogen/include/ui_mainwindow.h" line="653"/>
         <source>NVMe SSD</source>
         <translation>NVMe SSD</translation>
     </message>
     <message>
         <location filename="../../src/mainwindow.ui" line="1257"/>
-        <location filename="../../build/kdiskmark_autogen/include/ui_mainwindow.h" line="654"/>
         <source>Use Fusion</source>
         <translation>Fusion</translation>
     </message>
     <message>
         <location filename="../../src/mainwindow.ui" line="1265"/>
-        <location filename="../../build/kdiskmark_autogen/include/ui_mainwindow.h" line="655"/>
         <source>Stylesheet Light</source>
-        <translation>明るいスタイルシート</translation>
+        <translation>ライト用スタイルシート</translation>
     </message>
     <message>
         <location filename="../../src/mainwindow.ui" line="1273"/>
-        <location filename="../../build/kdiskmark_autogen/include/ui_mainwindow.h" line="656"/>
         <source>Stylesheet Dark</source>
-        <translation>暗いスタイルシート</translation>
+        <translation>ダーク用スタイルシート</translation>
     </message>
     <message>
         <location filename="../../src/mainwindow.ui" line="1281"/>
-        <location filename="../../build/kdiskmark_autogen/include/ui_mainwindow.h" line="657"/>
         <source>Do not apply</source>
         <translation>適用しない</translation>
     </message>
     <message>
         <location filename="../../src/mainwindow.ui" line="1292"/>
-        <location filename="../../build/kdiskmark_autogen/include/ui_mainwindow.h" line="658"/>
         <source>Use O_DIRECT</source>
         <translation>O_DIRECT を使用</translation>
     </message>
     <message>
-        <location filename="../../src/mainwindow.cpp" line="53"/>
+        <location filename="../../src/mainwindow.ui" line="1303"/>
+        <source>CoW detection</source>
+        <translation>CoW検出</translation>
+    </message>
+    <message>
+        <location filename="../../src/mainwindow.cpp" line="54"/>
         <source>The device is encrypted. Performance may drop.</source>
         <translation>デバイスが暗号化されています。性能が低下する場合があります。</translation>
     </message>
     <message>
-        <location filename="../../src/mainwindow.cpp" line="256"/>
-        <location filename="../../src/mainwindow.cpp" line="315"/>
+        <location filename="../../src/mainwindow.cpp" line="263"/>
+        <location filename="../../src/mainwindow.cpp" line="322"/>
         <source>Add a directory</source>
         <translation>ディレクトリを追加</translation>
     </message>
     <message>
-        <location filename="../../src/mainwindow.cpp" line="345"/>
-        <location filename="../../src/mainwindow.cpp" line="439"/>
-        <location filename="../../src/mainwindow.cpp" line="507"/>
+        <location filename="../../src/mainwindow.cpp" line="352"/>
+        <location filename="../../src/mainwindow.cpp" line="452"/>
+        <location filename="../../src/mainwindow.cpp" line="520"/>
         <source>MiB</source>
         <translation>MiB</translation>
     </message>
     <message>
-        <location filename="../../src/mainwindow.cpp" line="349"/>
-        <location filename="../../src/mainwindow.cpp" line="507"/>
+        <location filename="../../src/mainwindow.cpp" line="356"/>
+        <location filename="../../src/mainwindow.cpp" line="520"/>
         <source>GiB</source>
         <translation>GiB</translation>
     </message>
     <message>
-        <location filename="../../src/mainwindow.cpp" line="439"/>
-        <location filename="../../src/mainwindow.cpp" line="507"/>
+        <location filename="../../src/mainwindow.cpp" line="452"/>
+        <location filename="../../src/mainwindow.cpp" line="520"/>
         <source>KiB</source>
         <translation>KiB</translation>
     </message>
     <message>
-        <location filename="../../src/mainwindow.cpp" line="507"/>
+        <location filename="../../src/mainwindow.cpp" line="520"/>
         <source>Bytes</source>
         <translation>Bytes</translation>
     </message>
     <message>
-        <location filename="../../src/mainwindow.cpp" line="507"/>
+        <location filename="../../src/mainwindow.cpp" line="520"/>
         <source>TiB</source>
         <translation>TiB</translation>
     </message>
     <message>
-        <location filename="../../src/mainwindow.cpp" line="507"/>
+        <location filename="../../src/mainwindow.cpp" line="520"/>
         <source>PiB</source>
         <translation>PiB</translation>
     </message>
     <message>
-        <location filename="../../src/mainwindow.cpp" line="870"/>
-        <location filename="../../src/mainwindow.cpp" line="871"/>
-        <location filename="../../src/mainwindow.cpp" line="872"/>
-        <location filename="../../src/mainwindow.cpp" line="873"/>
-        <location filename="../../src/mainwindow.cpp" line="874"/>
+        <location filename="../../src/mainwindow.cpp" line="892"/>
+        <location filename="../../src/mainwindow.cpp" line="893"/>
+        <location filename="../../src/mainwindow.cpp" line="894"/>
+        <location filename="../../src/mainwindow.cpp" line="895"/>
+        <location filename="../../src/mainwindow.cpp" line="896"/>
         <source>Stop</source>
         <translation>Stop</translation>
     </message>
     <message>
-        <location filename="../../src/mainwindow.cpp" line="922"/>
+        <location filename="../../src/mainwindow.cpp" line="944"/>
         <source>Stopping...</source>
         <translation>Stopping...</translation>
     </message>
     <message>
-        <location filename="../../src/mainwindow.cpp" line="932"/>
+        <location filename="../../src/mainwindow.cpp" line="954"/>
         <source>Not available</source>
         <translation>利用できません</translation>
     </message>
     <message>
-        <location filename="../../src/mainwindow.cpp" line="932"/>
+        <location filename="../../src/mainwindow.cpp" line="954"/>
         <source>Directory is not specified.</source>
         <translation>ディレクトリが指定されていません。</translation>
     </message>
     <message>
-        <location filename="../../src/mainwindow.cpp" line="935"/>
-        <source>Confirmation</source>
-        <translation>確認</translation>
+        <location filename="../../src/mainwindow.cpp" line="1059"/>
+        <source>Copy-on-Write (CoW) is enabled on the selected directory.</source>
+        <translation>選択されたディレクトリで書き込み時コピー（CoW）が有効になっています。</translation>
     </message>
     <message>
-        <location filename="../../src/mainwindow.cpp" line="948"/>
+        <location filename="../../src/mainwindow.cpp" line="1060"/>
+        <source>This may affect performance results. Would you like to create a new subdirectory with CoW disabled?</source>
+        <translation>これはパフォーマンスの結果に影響を与える可能性があります。CoWを無効にした新しいサブディレクトリを作成しますか？</translation>
+    </message>
+    <message>
+        <source>Confirmation</source>
+        <translation type="vanished">確認</translation>
+    </message>
+    <message>
+        <location filename="../../src/mainwindow.cpp" line="964"/>
         <source>Benchmark Failed</source>
         <translation>ベンチマーク失敗</translation>
     </message>
@@ -463,7 +428,7 @@
         <translation>&lt;h1&gt;%1 MB/s&lt;br/&gt;%2 GB/s&lt;br/&gt;%3 IOPS&lt;br/&gt;%4 μs&lt;/h1&gt;</translation>
     </message>
     <message>
-        <location filename="../../src/mainwindow.cpp" line="193"/>
+        <location filename="../../src/mainwindow.cpp" line="200"/>
         <source>No FIO was found. Please install FIO before using KDiskMark.</source>
         <translation>FIO が見つかりませんでした。KDiskMark を使用する前に FIO をインストールしてください。</translation>
     </message>
@@ -472,61 +437,51 @@
     <name>Settings</name>
     <message>
         <location filename="../../src/settings.ui" line="14"/>
-        <location filename="../../build/kdiskmark_autogen/include/ui_settings.h" line="237"/>
         <source>Settings</source>
         <translation>設定</translation>
     </message>
     <message>
         <location filename="../../src/settings.ui" line="149"/>
-        <location filename="../../build/kdiskmark_autogen/include/ui_settings.h" line="238"/>
         <source>Block Size</source>
         <translation>ブロックサイズ</translation>
     </message>
     <message>
         <location filename="../../src/settings.ui" line="165"/>
-        <location filename="../../build/kdiskmark_autogen/include/ui_settings.h" line="239"/>
         <source>Queues</source>
         <translation>キュー数</translation>
     </message>
     <message>
         <location filename="../../src/settings.ui" line="181"/>
-        <location filename="../../build/kdiskmark_autogen/include/ui_settings.h" line="240"/>
         <source>Threads</source>
         <translation>スレッド数</translation>
     </message>
     <message>
         <location filename="../../src/settings.ui" line="257"/>
-        <location filename="../../build/kdiskmark_autogen/include/ui_settings.h" line="241"/>
         <source>Profile: Default</source>
         <translation>プロファイル: デフォルト</translation>
     </message>
     <message>
         <location filename="../../src/settings.ui" line="280"/>
-        <location filename="../../build/kdiskmark_autogen/include/ui_settings.h" line="242"/>
         <source>Type</source>
         <translation>タイプ</translation>
     </message>
     <message>
         <location filename="../../src/settings.ui" line="335"/>
-        <location filename="../../build/kdiskmark_autogen/include/ui_settings.h" line="243"/>
         <source>Profile: Peak Performance</source>
         <translation>プロファイル: ピーク性能</translation>
     </message>
     <message>
         <location filename="../../src/settings.ui" line="446"/>
-        <location filename="../../build/kdiskmark_autogen/include/ui_settings.h" line="244"/>
         <source>Profile: Demo</source>
         <translation>プロファイル: デモ</translation>
     </message>
     <message>
         <location filename="../../src/settings.ui" line="508"/>
-        <location filename="../../build/kdiskmark_autogen/include/ui_settings.h" line="245"/>
         <source>Measuring time</source>
         <translation>測定時間</translation>
     </message>
     <message>
         <location filename="../../src/settings.ui" line="530"/>
-        <location filename="../../build/kdiskmark_autogen/include/ui_settings.h" line="246"/>
         <source>Interval time</source>
         <translation>測定間隔</translation>
     </message>
