@@ -10,8 +10,11 @@ int main(int argc, char *argv[])
     QCoreApplication::setApplicationName(QStringLiteral(PROJECT_NAME));
     QCoreApplication::setApplicationVersion(QStringLiteral("%1.%2.%3").arg(PROJECT_VERSION_MAJOR)
                                             .arg(PROJECT_VERSION_MINOR).arg(PROJECT_VERSION_PATCH));
+    QCoreApplication::setOrganizationName(QStringLiteral(PROJECT_NAME));
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     QApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
+#endif
 
     SingleApplication a(argc, argv);
 
